summaryrefslogtreecommitdiffstats
path: root/src/core/nodes/qnode.cpp
diff options
context:
space:
mode:
authorSean Harmer <sean.harmer@kdab.com>2015-10-12 20:45:19 +0100
committerPaul Lemire <paul.lemire@kdab.com>2015-10-13 13:19:50 +0000
commit7c971e0e7791ab38d7d3d8ebc25468c44cbe49c5 (patch)
tree53197a9e5eb7501d6f5b497f70c25dad9c265a6f /src/core/nodes/qnode.cpp
parent0bfd20ad3b8eb3edec8d6317af9eb5504f8c0871 (diff)
Move Qt3DCore into Qt3DCore namespace
Update other aspects, tests and examples accordingly. Change-Id: Ib1bcf0bdf4f5aec4422dc0c80bfc32b27fb1a317 Reviewed-by: Paul Lemire <paul.lemire@kdab.com>
Diffstat (limited to 'src/core/nodes/qnode.cpp')
-rw-r--r--src/core/nodes/qnode.cpp60
1 files changed, 30 insertions, 30 deletions
diff --git a/src/core/nodes/qnode.cpp b/src/core/nodes/qnode.cpp
index 3338b6cae..9ba2fe3c0 100644
--- a/src/core/nodes/qnode.cpp
+++ b/src/core/nodes/qnode.cpp
@@ -52,12 +52,12 @@
QT_BEGIN_NAMESPACE
-namespace Qt3D {
+namespace Qt3DCore {
QHash<QNodeId, QNode *> QNodePrivate::m_clonesLookupTable = QHash<QNodeId, QNode *>();
/*!
- \class Qt3D::QNodePrivate
+ \class Qt3DCore::QNodePrivate
\internal
*/
QNodePrivate::QNodePrivate()
@@ -274,7 +274,7 @@ void QNodePrivate::setArbiter(QLockableObserverInterface *arbiter)
/*!
Called when one or more backend aspects sends a notification \a change to the
- current Qt3D::QNode instance.
+ current Qt3DCore::QNode instance.
\note This method should be reimplemented in your subclasses to properly
handle the \a change.
@@ -384,46 +384,46 @@ void QNodePrivate::nodePtrDeleter(QNode *q)
/*!
- \class Qt3D::QNode
+ \class Qt3DCore::QNode
\inherits QObject
\inmodule Qt3DCore
\since 5.5
- \brief Qt3D::QNode is the base class of all Qt3D node classes used to build a
+ \brief Qt3DCore::QNode is the base class of all Qt3D node classes used to build a
Qt3D scene.
- The owernship of Qt3D::QNode is determined by the QObject parent/child
- relationship between nodes. By itself a Qt3D::QNode has no visual appearance
+ The owernship of Qt3DCore::QNode is determined by the QObject parent/child
+ relationship between nodes. By itself a Qt3DCore::QNode has no visual appearance
and no particular meaning, it is there as a way of building a node based tree
structure.
- The parent of a Qt3D::QNode instance can only be another Qt3D::QNode
+ The parent of a Qt3DCore::QNode instance can only be another Qt3DCore::QNode
instance.
- Each Qt3D::QNode instance has a unique id that allows it to be recognizable
+ Each Qt3DCore::QNode instance has a unique id that allows it to be recognizable
from other instances.
- When properties are defined on a Qt3D::QNode subclass, their NOTIFY signal
+ When properties are defined on a Qt3DCore::QNode subclass, their NOTIFY signal
will automatically generate notifications that the Qt3D backend aspects will
receive.
- When subclassing Qt3D::QNode make sure to call QNode::cleanup() from your
+ When subclassing Qt3DCore::QNode make sure to call QNode::cleanup() from your
subclass's destructor to ensure proper notification to backend aspects.
- Faiure to do so will result in crashes when one of your Qt3D::QNode
+ Faiure to do so will result in crashes when one of your Qt3DCore::QNode
subclass instance is eventually destroyed.
- \sa Qt3D::QEntity, Qt3D::QComponent
+ \sa Qt3DCore::QEntity, Qt3DCore::QComponent
*/
/*!
- Creates a new Qt3D::QNode instance with parent \a parent.
+ Creates a new Qt3DCore::QNode instance with parent \a parent.
- \note The backend aspects will be notified that a Qt3D::QNode instance is
+ \note The backend aspects will be notified that a Qt3DCore::QNode instance is
part of the scene only if it has a parent; unless this is the root node of
the Qt3D scene.
- \sa setParent(Qt3D::QNode *)
+ \sa setParent(Qt3DCore::QNode *)
*/
QNode::QNode(QNode *parent)
: QObject(*new QNodePrivate, parent)
@@ -451,11 +451,11 @@ QNode::QNode(QNodePrivate &dd, QNode *parent)
}
/*!
- Copies all the attributes from \a ref to the current Qt3D::QNode instance.
+ Copies all the attributes from \a ref to the current Qt3DCore::QNode instance.
- \note When subclassing Qt3D::QNode you should reimplement this method and
+ \note When subclassing Qt3DCore::QNode you should reimplement this method and
always call the copy method on the base class. This will ensure that when cloned,
- the Qt3D::QNode is properly initialized.
+ the Qt3DCore::QNode is properly initialized.
*/
void QNode::copy(const QNode *ref)
{
@@ -467,11 +467,11 @@ void QNode::copy(const QNode *ref)
QNode::~QNode()
{
- Q_ASSERT_X(QNodePrivate::get(this)->m_wasCleanedUp, Q_FUNC_INFO, "QNode::cleanup should have been called by now. A Qt3D::QNode subclass didn't call QNode::cleanup in its destructor");
+ Q_ASSERT_X(QNodePrivate::get(this)->m_wasCleanedUp, Q_FUNC_INFO, "QNode::cleanup should have been called by now. A Qt3DCore::QNode subclass didn't call QNode::cleanup in its destructor");
}
/*!
- Returns the id that uniquely identifies the Qt3D::QNode instance.
+ Returns the id that uniquely identifies the Qt3DCore::QNode instance.
*/
const QNodeId QNode::id() const
{
@@ -480,7 +480,7 @@ const QNodeId QNode::id() const
}
/*!
- Returns the immediate Qt3D::QNode parent, null if the node has no parent.
+ Returns the immediate Qt3DCore::QNode parent, null if the node has no parent.
*/
QNode *QNode::parentNode() const
{
@@ -519,12 +519,12 @@ bool QNode::blockNotifications(bool block)
}
/*!
* Sets the parent node of the current Qt3D::QNode instance to \a parent.
* Setting the parent will notify the backend aspects about current Qt3D::QNode
* instance's parent change.
*
* \note if \a parent happens to be null, this will actually notify that the
* current Qt3D::QNode instance was removed from the scene.
*/
void QNode::setParent(QNode *parent)
{
@@ -537,8 +537,8 @@ void QNode::setParent(QNode *parent)
}
/*!
* Returns a list filled with the Qt3D::QNode children of the current
* Qt3D::QNode instance.
*/
QNodeList QNode::childrenNodes() const
{
@@ -596,10 +596,10 @@ QNode *QNode::clone(QNode *node)
/*!
* This methods can only be called once and takes care of notyfing the backend
* aspects that the current Qt3D::QNode instance is about to be destroyed.
*
* \note It must be called by the destructor of every class subclassing
* Qt3D::QNode that is clonable (using the QT3D_CLONEABLE macro).
*/
void QNode::cleanup()
{
@@ -614,7 +614,7 @@ void QNode::cleanup()
}
}
-} // namespace Qt3D
+} // namespace Qt3DCore
QT_END_NAMESPACE
@@ -519,12 +519,12 @@ bool QNode::blockNotifications(bool block)
}
/*!
- * Sets the parent node of the current Qt3D::QNode instance to \a parent.
- * Setting the parent will notify the backend aspects about current Qt3D::QNode
+ * Sets the parent node of the current Qt3DCore::QNode instance to \a parent.
+ * Setting the parent will notify the backend aspects about current Qt3DCore::QNode
* instance's parent change.
*
@@ -519,12 +519,12 @@ bool QNode::blockNotifications(bool block)
*
* \note if \a parent happens to be null, this will actually notify that the
- * current Qt3D::QNode instance was removed from the scene.
+ * current Qt3DCore::QNode instance was removed from the scene.
*/
void QNode::setParent(QNode *parent)
@@ -537,8 +537,8 @@ void QNode::setParent(QNode *parent)
}
/*!
- * Returns a list filled with the Qt3D::QNode children of the current
- * Qt3D::QNode instance.
+ * Returns a list filled with the Qt3DCore::QNode children of the current
+ * Qt3DCore::QNode instance.
*/
QNodeList QNode::childrenNodes() const
@@ -596,10 +596,10 @@ QNode *QNode::clone(QNode *node)
/*!
* This methods can only be called once and takes care of notyfing the backend
- * aspects that the current Qt3D::QNode instance is about to be destroyed.
+ * aspects that the current Qt3DCore::QNode instance is about to be destroyed.
*
* \note It must be called by the destructor of every class subclassing
@@ -596,10 +596,10 @@ QNode *QNode::clone(QNode *node)
*
* \note It must be called by the destructor of every class subclassing
- * Qt3D::QNode that is clonable (using the QT3D_CLONEABLE macro).
+ * Qt3DCore::QNode that is clonable (using the QT3D_CLONEABLE macro).
*/
void QNode::cleanup()